@@ -19,7 +19,7 @@ require Math::Base::Convert::Bases;	# drag in BASES
 	Exporter
 );
 
-$VERSION = do { my @r = (q$Revision: 0.10 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 0.11 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 @EXPORT_OK   = ( qw( cnv cnvpre cnvabs basemap ), @BASES );
 %EXPORT_TAGS = (
@@ -318,6 +318,7 @@ Math::Base::Convert - very fast base to base conversion
 	DNA		base 4 upper case DNA
 	oct		base 8 octal
 	dec		base 10 decimal
+	d11		base 11 0123456789.
 	hex		base 16 lower case hex
 	HEX		base 16 upper case HEX
 	b62		base 62
@@ -376,6 +377,7 @@ The functions below return a reference to an array
   DNA => ['A','T','C','G'],	{default}	  # uc DNA
   oct => ['0'..'7']				  # octal
   dec => ['0'..'9']				  # decimal
+  d11 => ['0'..'9', '.']			  # 0123456789.
   hex => ['0'..'9', 'a'..'f']			  # lc hex
   HEX => ['0'..'9', 'A'..'F']	{default}	  # uc HEX
   b62 => ['0'..'9', 'a'..'z', 'A'..'Z']		  # base 62
@@ -442,7 +444,7 @@ context for the 'octal' designator.
   base as text
 	$converted = convbase($number,'oct');
 
-Conversion to/from arbitary bases i.e.
+Conversion to/from arbitrary bases i.e.
 
   $converted = cnv($number); # dec -> hex (default)
   $converted = cnv($number,oct);	# oct to HEX
@@ -603,6 +605,7 @@ Conditional EXPORT functions
 	bin
 	oct
 	dec
+	d11
 	heX
 	HEX
 	b62
